Compute the 16 pair of coordinates necessary for using the objective version of the Lamb method

get_lamb_points(x, y)

Arguments

x

longitude coordinate of the central point of the scheme.

y

latitude coordinate of the central point of the scheme.

Value

a data.frame with the 16 points of coordinates.

Examples

points <- get_lamb_points(x = -5, y = 40) points
#> lat lon label #> 1 45 10 P6 #> 2 40 10 P10 #> 3 35 10 P14 #> 4 50 0 P2 #> 5 45 0 P5 #> 6 40 0 P9 #> 7 35 0 P13 #> 8 30 0 P16 #> 9 50 -10 P1 #> 10 45 -10 P4 #> 11 40 -10 P8 #> 12 35 -10 P12 #> 13 30 -10 P15 #> 14 45 -20 P3 #> 15 40 -20 P7 #> 16 35 -20 P11