Perform a Principal Component Analysis on a RasterStack
raster_pca(raststack, aggregate = 0, focal = 0)
| raststack | Raster Stack. |
|---|---|
| aggregate | Integer. Aggregation factor based on function |
| focal | Integer. smooth filter based on function |
a list with:
A raster stack containing the results of the PCA
A data frame containing the main results of the PCA (standard deviation, proportion of variance and cumulative variance